# frozen_string_literal: true

require 'parallel'
require 'shellwords'
require 'thor'
require 'zippy/parser'

module Zippy
  class CLI < Thor
    desc 'download <url>', 'Download single <URL>'
    def download(url)
      down_url = Zippy::Parser.parse(url)
      system format('wget -cq --show-progress %s', Shellwords.escape(down_url))
    end

    desc 'batch <file> <simultaneous>', 'Parse each line of <FILE>'
    def batch(file, n = 0)
      links = File.readlines(file).each.map(&:strip)
      Parallel.each(links, in_threads: n.to_i) { |link| download(link) }
    end
  end
end
